/*
	skeleton_main.c	Rev. 1.0

	Evaluation board: ALS-G3-1369
	Software: VisualDSP++ Rev. 4.5
	
	The SKELETON PROJECT is intended to use as base
	for LABINVERTER control application
	
	ALFINE P.E.P., 03.2008	
*/



#include <21369.h>
#include <def21369.h>
#include <Cdef21369.h>
#include <signal.h>
#include <math.h>
#include <sru21369.h>
#include "..\Common_files\sys_def.h"
#include "..\Common_files\sys_serv.h"
#include "..\Common_files\1369_cons.h"


void PWM_isr(int signal);  //PWM interrupt service routine

void INVERR_isr(int signal);  //DAI interrupt (Inverter ERROR service)

void ADC_isr(int signal);  //ADC interrupt service routine


//!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
void SYS_Init(void);  //System Setup - OBLIGATORY for Eval Board
//!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

//System const.
#define	CLK_IN_FREQ		20e6	//Processor Input Clock freq. [Hz]
#define	CORE_FREQ		320e6	//Core Clock freq. [Hz]

//PWM Generator definitions
#define	PWM_FREQ		10e3  //PWM Carrier freq. [Hz]
						//MIN value of PWM carier is about 2441 Hz !
#define PWM_DIV			CORE_FREQ/(4*PWM_FREQ)  //Divisor for PWM in SINGLE_UPDATE Mode
#define PWM_DT			3.5 //Dead time value [us]
#define DT_DIV			1e-6*PWM_DT*CORE_FREQ/4  //Dead time divider

//ciag dalszy

//Sampling/system parameters
#define ADC_CONV_FREQ	1e5  //ADCs sample rate [Hz]
#define	FRS_DIV			CLK_IN_FREQ/ADC_CONV_FREQ  //divider for PCG

#define	ADC_CONFIG		0x0000fc00  //ADC cofiguration word
									//All channels active, +/-2xVREF input voltage range
									//external VREF, on-chip VREF buffers enabled

ADC_Util data_in_1, data_in_2;  //data from ADCs
DAC_Util data_out;  //data for DAC


//User/application definitions and variables
#define		PI			3.1415927
#define		PERIOD		100
#define		dlt_A_ref	0.1

int	status, duty=0, t;

unsigned int kbd_state;

float A_ref=0, s_ref=0;


main()
{
 
  //!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!     
  SYS_Init();  //System initilization - OBLIGATORY program line !!!
  //!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  
  INV_ENA();  //enable inverter interface
      
  clr_LCD();  //clear LCD memory
  
  lprintf_LCD(0,"%s","ALS-G3-1369 Rev. 0.1");  //system message
  
  lprintf_LCD(64,"%s","Project: skelton.dpj");  //system message
  
  lprintf_LCD(84,"%s","A_ref=");  //system message

  
 // interrupt(SIG_SPIL, PWM_isr);  //Enable low priority PWM interrupt (SPI IVT)
  
  //interrupt(SIG_DAIH, INVERR_isr);  //enable DAI/HIGH priority interrupt
  
 // interruptf(SIG_IRQ0, ADC_isr);  //enable external No 0 interrupt

  INV_START();  //activation own inverter control block
      
  while(1)
  {
    kbd_state = read_kbd();
    
    switch(kbd_state)
    {
      case K1: if((A_ref+dlt_A_ref)<1.0)  //A_ref UP
                 A_ref=A_ref+dlt_A_ref;
               break;
      case K2: if((A_ref-dlt_A_ref)>0)  //A_ref DOWN
                 A_ref=A_ref-dlt_A_ref;
               break;

      default: break;
    }
    
    lprintf_LCD(90,"%f4.1",A_ref);  //print current A_ref value
    
    wait_ms(200);  //delay  

    idle();  //put DSP core in idle state for energy conservation
  }
    
}



void ADC_isr(int signal)
{
 
  set_flag(SET_FLAG1, CLR_FLAG);  //for debuging purposes only 

  //Place USER code here
  //...
  #define	DAC_SCALE	32767  //for scaling data for DAC
  
    
  ADC1_Data_In(ADC_CONFIG, &data_in_1);  //read data from ADC No 1
  ADC2_Data_In(ADC_CONFIG, &data_in_2);  //and ADC No 2
  
  data_out.Ch_A = data_in_2.Ch_5;//DAC_SCALE*s_ref;  //put data into 'DAC_Util' structure
  data_out.Ch_B	= data_in_1.Ch_6;  //put data from ADC No 1/channel 1 directly to DAC channel B
  data_out.Ch_C	= data_in_1.Ch_5;  //put data from ADC No 2/channel 1 directly to DAC channel C

  DAC_Data_Out(&data_out);  //put data into DAC

  set_flag(SET_FLAG1, SET_FLAG);  //for debuging purposes only 

}



void PWM_isr(int signal)
{
  //set_flag(SET_FLAG1, SET_FLAG);  //for debuging purposes only
	
  *pPWMGSTAT = PWM_STAT0 | PWM_STAT1;  //Write into PWMGSTAT to reset PWM_INT bits !

  
  //Place USER code here
  //...
  s_ref=A_ref*sinf(2*PI*t++/PERIOD);  //software generated a SIN function
  if(t==PERIOD)
    t=0;
  
  PWM_Duty(PWM_DIV/4*s_ref,-PWM_DIV/4,PWM_DIV/4);  //change PWM duty cycle
  													//PWM carrier waveform in channel PWM0/1
  													//is modulated sinusoidally

  WDG_RFSH();  //inverter interface WATCHDOG refreshing
  				//- neccessary for enabling inverter interface
		      
  //set_flag(SET_FLAG1, CLR_FLAG);
}



void INVERR_isr(int signal)
{
	//set_flag(SET_FLAG1, TGL_FLAG);  //for debuging purposes only
  	
	status = *pDAI_IRPTL_H;  //clear DAI_H interrupt latch bit
	
	//Place User code here
  	//...
  	
}



void SYS_Init(void)
{

    
  //!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  PLL_SDCLK_Init();  //OBLIGATORY program line
  //!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  
  
  //Configure SRU
  //Generating Code for connecting:DAI_PIN19 to MISCA0
  //- INVERR signal service
  SRU (LOW, PBEN19_I);
  SRU (DAI_PB19_O, MISCA0_I);
   
  //Interrupt system configuration
  //- DAI
  *pDAI_IRPTL_FE = SRU_EXTMISCA0_INT;  //FALLING EDGE sensitivity
  *pDAI_IRPTL_PRI = SRU_EXTMISCA0_INT;	//PRIORITY REG must be SET UP to take effect !
  
  
  *pSYSCTL = *pSYSCTL | IRQ0EN;  //configure FLAG0 as ext. interrupt source
  asm volatile ("bit set MODE2 1;");  //IRQ0 - edge activated

  ADC1_Data_In(ADC_CONFIG, &data_in_1);  //first configure ADC No 1
  ADC2_Data_In(ADC_CONFIG, &data_in_2);  //and ADC No 2
 
  Set_PCG(FRS_DIV);  //activate ADCONV_START signal (PCG_A of P2)
  
  PWM_Init(PWM_DIV,DT_DIV);  //PWM unit initializaion
  
  init_LCD(); //LCD module initialization
}
